==> owncloud-8.1.0p2.tgz: owncloud/apps/activity/l10n/bg_BG.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Активност",
    "Personal activity feed for %s" : "Личен поток за активност на %s.",
    "Your feed URL is invalid" : "Потока е с невалиден адрес",
    "Your settings have been updated." : "Вашите настройки са актуализирани.",
    "Activity notification" : "Известия за активност",
    "All Activities" : "Активност на всички",
    "Activities by you" : "Вашата активност",
    "Activities by others" : "Активността на другите",
    "\"remote user\"" : "\"отдалечен потребител\"",
    "in %s" : "в %s",
    "%s and %s" : "%s и %s",
    ", " : ", ",
    "_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_" : ["%s и <strong class=\"tooltip\" title=\"%s\">още %n</strong>.","%s и <strong class=\"tooltip\" title=\"%s\">още %n</strong>."],
    "_%s and %n more_::_%s and %n more_" : ["%s и %n друга","%s и още %n"],
    "Hello %s," : "Здравей %s,",
    "You are receiving this email because in the last hour the following things happened at %s" : "Получавате този имейл, защото през последния час се случиха следните неща в %s.",
    "You are receiving this email because in the last day the following things happened at %s" : "Получавате този имейл, защото през последния ден се случиха следните неща в %s.",
    "You are receiving this email because in the last week the following things happened at %s" : "Получавате този имейл, защото през последната седмица се случиха следните неща в %s.",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "Notifications" : "Известия",
    "Mail" : "Поща",
    "Stream" : "Поток",
    "List your own actions in the stream" : "Показване на собствените действия в потока",
    "Notify about your own actions via email" : "Уведомяване за собствени действия чрез електронна поща",
    "You need to set up your email address before you can receive notification emails." : "Първо трябва да настроите вашия имейл адрес, преди да започнете да получавате известия.",
    "Send emails:" : "Изпращане на имейли:",
    "Hourly" : "На всеки час",
    "Daily" : "Ежедневно",
    "Weekly" : "Седмично",
    "Activity feed" : "Поток за активност",
    "Enable RSS feed" : "Разрешаване на RSS източници.",
    "No more events to load" : "Няма повече известия за зареждане.",
    "Files" : "Файлове"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.3.tgz: owncloud/apps/activity/l10n/bg_BG.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Активност",
    "Personal activity feed for %s" : "Личен поток за активност на %s.",
    "Your feed URL is invalid" : "Потока е с невалиден адрес",
    "Your settings have been updated." : "Вашите настройки са актуализирани.",
    "Mail" : "Поща",
    "Stream" : "Поток",
    ", " : ", ",
    "This stream will show events like additions, changes & shares" : "Потокът ще покаже събития като допълнения, изменения и споделяния",
    "There are no events for this filter" : "Няма събития за този филтър",
    "Today" : "Днес",
    "Yesterday" : "Вчера",
    "\"remote user\"" : "\"отдалечен потребител\"",
    "Activity notification" : "Известия за активност",
    "All Activities" : "Активност на всички",
    "Activities by you" : "Вашата активност",
    "Activities by others" : "Активността на другите",
    "%s and %s" : "%s и %s",
    "Hello %s," : "Здравей %s,",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* и %n още","* и %n още "],
    "List your own actions in the stream" : "Показване на собствените действия в потока",
    "Notify about your own actions via email" : "Уведомяване за собствени действия чрез електронна поща",
    "You need to set up your email address before you can receive notification emails." : "Първо трябва да настроите вашия имейл адрес, преди да започнете да получавате известия.",
    "Send emails:" : "Изпращане на имейли:",
    "Hourly" : "На всеки час",
    "Daily" : "Ежедневно",
    "Weekly" : "Седмично",
    "Activity feed" : "Поток за активност",
    "Enable RSS feed" : "Разрешаване на RSS източници.",
    "No activity yet" : "Няма активност все още",
    "No more events to load" : "Няма повече известия за зареждане.",
    "Files" : "Файлове"
},
"nplurals=2; plural=(n != 1);");
